@@ -5,14 +5,16 @@ use warnings;
 
 use base qw(Text::CSV::Base);
 
-our $VERSION = '0.200_001';
+our $VERSION = '0.200_002';
 
 sub new {
     my ($self, $hash) = @_;
     if ( $hash and $hash -> {binary} ) {
-        if ($^V >= 5.010 && warnings::enabled("deprecated")) {
+        if ( eval { require 5.10.0 } ) { 
+	  if (warnings::enabled("deprecated")) {
             warnings::warn("deprecated",
                 "binary is deprecated: use Text::CSV");
+	  }
         }
 	return Text::CSV::Base->new( $hash );
     }
